@@ -12,7 +12,7 @@ from apis_core.apis_metainfo.tables import (
     generic_render_end_date_written
 )
 from apis_core.apis_relations.models import AbstractRelation
-
+from apis_ampel.template_column import AmpelTemplateColumn
 empty_text_default = 'There are currently no relations'
 
 
@@ -85,6 +85,12 @@ def get_generic_relation_listview_table(relation_name):
                 ]
             )
 
+            if "apis_ampel" in settings.INSTALLED_APPS:
+                from apis_ampel.helper_functions import is_ampel_active
+                if is_ampel_active(relation_name):
+                    self.base_columns['ampel'] = tables.TemplateColumn(template_name = "ampel/ampel_template_column.html", verbose_name="Ampel")
+
+
             super().__init__(*args, **kwargs)
 
 
@@ -238,7 +244,7 @@ def get_generic_relations_table(relation_class, entity_instance, detail=None):
                 else:
                     an.other_relation_type = getattr(an.relation_type, "label_reverse")
 
-
+ 
             super().__init__(data, *args, **kwargs)
 
 
@@ -262,6 +268,17 @@ def get_generic_relations_table(relation_class, entity_instance, detail=None):
                     verbose_name="Related " + other_related_entity_class_name.title()
                 )
 
+                # __g.pirgie__ deactivated as it caused problems with the ajax forms
+                # if "apis_ampel" in settings.INSTALLED_APPS:
+                #     from apis_ampel.helper_functions import is_ampel_active
+               
+                #     if is_ampel_active(relation_class.__name__):
+                #         self.base_columns['ampel'] = tables.TemplateColumn(template_name = "ampel/edit_inline_table_column.html", verbose_name="Ampel")
+
+
+
+
+
                 super().__init__(data=data, *args, **kwargs)
 
 
@@ -317,6 +334,14 @@ def get_generic_relations_table(relation_class, entity_instance, detail=None):
                         template_name='apis_relations/references_button_generic_ajax_form.html'
                     )
 
+                if "apis_ampel" in settings.INSTALLED_APPS:
+                        from apis_ampel.helper_functions import is_ampel_active
+               
+                        if is_ampel_active(relation_class.__name__):
+                            self.base_columns['ampel'] = tables.TemplateColumn(template_name = "ampel/ampel_edit_template_column.html", verbose_name="Ampel")
+
+
+
                 super().__init__(*args, **kwargs)
 
 
@@ -341,7 +366,7 @@ class EntityUriTable(tables.Table):
 
 class LabelTableBase(tables.Table):
 
-    label2 = tables.TemplateColumn(template_name="apis_relations/labels_label.html")
+    label = tables.TemplateColumn(template_name="apis_relations/labels_label.html")
 
     # reuse the logic for ordering and rendering *_date_written
     # Important: The names of these class variables must correspond to the column field name,
@@ -359,7 +384,7 @@ class LabelTableBase(tables.Table):
         # Note that as the next attribute 'sequence' builds on this list 'fields', the order defined within this list
         # will be reused for the tuple 'sequence'. So if the order needs to be changed, better do it here in the list 'fields'.
         fields = ['start_date_written', 'end_date_written', 'label_type', 'isoCode_639_3']
-        sequence = ('label2',) + tuple(fields)
+        sequence = ('label',) + tuple(fields)
 
         # add class="paleblue" to <table> tag
         attrs = {
